# Original Author: Codec04
# Re-built by Itz-fork
# Project: Gofile2

from .gofile2 import Gofile
from .async_gofile2 import Async_Gofile

__version__ = "v1.2"